# $Header: /raid/cvsroot/rt/etc/config.pm,v 1.11.2.45 2000/08/21 05:12:16 jesse Exp $	

# This is where RT's base configuration is stored.

package RT;

# {{{ Base Configuration (everything below should be set by the Makefile)

# name of RT installation
# Use a smart name, it's not smart changing this, unless you know
# exactly what you're doing.
$rtname="!!RT_MAIL_TAG!!";  

# Domain name and hostname
$domain="!!RT_DOMAIN!!";
$host="!!RT_HOST!!";
 
# $passwd_min defines the minimum length for user passwords.
$user_passwd_min = "!!RT_USER_PASSWD_MIN!!";

#Timezone
$ENV{'TZ'} = 'US/Eastern'; #TODO: Bogus hack to deal with Date::Manip whining


# }}}

# {{{ Mail Gateway configuration

# If $BouncesToRTOwner is defined, RT will send mail that it believes 
# might be a bounce to $RT::OwnerEmail
$BouncesToRTOwner = 1;


# If $StoreBounces is defined, RT will record messages that it believes 
# might be autogenerated and might lead to mail loops. 
# As it does this, it will try to be careful not to send mail to the 
# sender of these messages
$StoreBounces = undef;


#
#
# This subroutine converts email addresses into canonical form.
# it takes one email address in and returns the proper canonical
# form. You can dump whatever your proper local config is in here
sub CanonicalizeAddress {
	my $email = shift;
	# Example: the following rule would treat all email
	# coming from a subdomain as coming from second level domain
	# foo.com
	#$email =~ s/\@(.*).foo.com/\@foo.com/;
	return ($email)
}
# }}}


# {{{ Logging

# Logging.  The default is to log anything except debugging
# information to a logfile.  Check the Log::Dispatch POD for
# information about how to get things by syslog, mail or anything
# else, get debugging info in the log, etc.  It might generally make
# sense to send error and higher by email to some administrator.  For
# heavens sake; be sure that the email goes directly to a mailbox, and
# not via RT :)  Mail loops will generate a critical log message.

# I'm running this stuff to SysLog myself, but that's a bit more
# complex - actually I had to fight a bit with Sys::Syslog and h2ph to
# get it working.  I really don't want RT to break on such a stupid
# thing as logging, so I'll leave logging to file as the default.

#    -- Tobix

use Log::Dispatch 1.6;
use Log::Dispatch::File;
use Log::Dispatch::Screen;

$Logger=Log::Dispatch->new();
$Logger->add(Log::Dispatch::File->new
	     ( name=>'rtlog',
	       min_level=>'info',
	       filename=>'!!RT_LOGFILE!!',
	       mode=>'append',
	       callback => sub {my %p=@_; return "$p{message}\n"}
	     ));
$Logger->add(Log::Dispatch::Screen->new
	     ( name => 'screen',
	       min_level => 'err',
	       stderr => 1
	     ));
# }}}

# {{{ Options for the webui
%WebOptions=
    (
     # This is for putting in more user-actions at the Transaction
     # bar.  I will typically add "Enter bug in Bugzilla" here.:
     ExtraTransactionActions => sub { return ""; },

     # Here you can modify the list view.  Be aware that the web
     # interface might crash if TicketAttribute is wrongly set.
     # Consult the docs (if somebody is going to write them?) your
     # local RT hacker or eventually the rt-users / rt-devel
     # mailinglists
     QueueListingCols => 
      [
       { Header     => 'Ticket Id',
	 TicketLink => 1,
	 TicketAttribute => 'Id'
	 },

       { Header     => 'Take it!',
	 TicketLink => 1,
	 Constant   => 'Take',
	 ExtraLinks => '&Action=Take'
	 },

       { Header => 'Queue',
	 TicketAttribute => 'QueueObj->QueueId'
	 },

       { Header => 'Status',
	 TicketAttribute => 'Status'
	 },

       { Header => 'Told',
	 TicketAttribute => 'LongSinceToldAsString'
	 },

       { Header => 'Age',
	 TicketAttribute => 'AgeAsString'
	 },

       { Header => 'Last',
	 TicketAttribute => 'LongSinceUpdateAsString'
	 },

       # TODO: It would be nice with a link here to the Owner and all
       # other request owned by this Owner.
       { Header => 'Owner',
	 TicketAttribute => 'OwnerObj->UserId'
       },

       # TODO: We need a link here to a page containing this
       # requestors activity (ticket listing) and notes/similar stored
       # about the requestor
       { Header => 'Requestor(s)',
	 TicketAttribute => 'RequestorsAsString'
	 },

       { Header     => 'Subject',
	 TicketAttribute => 'Subject'
	 }
      ]
     );

# }}}

# {{{ RT Linking Interface
# A hash table of convertion subs to be used for transforming RT Link
# URIs to URLs in the web interface.  If you want to use RT towards
# locally installed databases, this is the right place to configure it.
# (TODO!)
%URI2HTTP=
    (
     'fsck.com-rt' => sub {warn "stub!";},
     'mozilla.org-bugzilla' => sub {warn "stub!"},
     'fsck.com-kb' => sub {warn "stub!"}
     );

# A hash table of subs for fetching content from an URI
%ContentFromURI=   
    (
     'fsck.com-rt' => sub {warn "stub!";},
     'mozilla.org-bugzilla' => sub {warn "stub!"},
     'fsck.com-kb' => sub {warn "stub!"}
     );

# If you want to use those, ask at rt-devel or to tobix@fsck.com for
# advices.

# }}}



# {{{ Database Configuration

# before doing a "make install" in /usr/local/rt/src you NEED to change the 
# password below and change the apropriate line in /usr/local/rt/etc/mysql.acl	
$DatabasePassword="!!DB_RT_PASS!!";

# host is the fqdn of your Mysql server
# if it's on localhost, leave it blank for enhanced performance
$DatabaseHost="!!DB_HOST!!";

#The name of the database user (inside the database) 
$DatabaseUser="!!DB_RT_USER!!";
    

#$dbname is the name of the RT's database on the Mysql server 
$RT::DatabaseName="!!DB_DATABASE!!";

# $rt_db is the database driver beeing used - i.e. MySQL.
$DatabaseType="!!DB_TYPE!!";

# }}}

# {{{ Mail sending configuration

#$MailAlias is a generic alias to send mail to for any request
#already in a queue because of the nature of RT, mail sent to any
#correspondence address will get put in the right place and mail sent
#to any comment address will also get sent to the right place.  The
#queue_dependent ones are only really important for assigning new
#requests to the correct queue

#This is the default address that will be listed in 
#From: and Reply-To: headers of mail tracked by RT

$MailAlias = "!!RT_MAIL_ALIAS!!";
$CorrespondAddress=$MailAlias;
$CommentAddress="!!RT_COMMENT_MAIL_ALIAS!!";


## TODO: Mail::Internet might need some configuration.

## Places to search for the signature:
#@Signature=('$home/.signature','$home/.signature.rt','/etc/rt/signatures/$userid');

# }}}

# {{{ MIME Object storage configuration
# 
# So far, this is all placeholders
#
#
# Maximum MIME Object Size

# Drop on the ground if it's over x kb
# Return to sender if it's over x kb

# MIME Object types to drop on the floor
# MIME Object types to return to sender
# MIME Object types to forward to RT Owner
# MIME Object types to store on disk
# MIME Object types to store in the database

# If an object doesn't meet any of the above criteria:

# Store on disk if it's over x kb

# Otherwise store it in the DB

# }}}

# {{{ WebRT Configuration
# Define the directory name to be used for images in rt web
# documents.

$WebrtImagePath = "!!WEB_IMAGE_PATH!!";
$WebPath = "!!WEB_PATH!!";
$WebURL = "http://$host\.$domain/$WebPath/";

# }}}

# {{{ Localization configuration

#  This is the default locale used by RT when deciding what version of the strings
# to show you
$DefaultLocale = "!!DEFAULT_LOCALE!!";

# This is the directory that .po files live in.

$LocalePath = "!!LOCALE_PATH!!";

# }}}

# {{{  No User servicable parts inside 
#

#RT's "nobody user" is a genuine database user. its ID lives here.
$Nobody=2;



## This is the default handling of warnings and die'ings in the code
## (including other used modules - maybe except for errors catched by
## Mason).  It will log all problems through the standard logging
## mechanism (see above).

$SIG{__WARN__} = sub {$RT::Logger->log(level=>'warning',message=>$_[0])};

#When we call die, trap it and log->crit with the value of the die.

$SIG{__DIE__}  = sub {
    unless ($^S || !defined $^S ) {

   	 $RT::Logger->crit("$_[0]"); 
	exit(-1);
	}
    else {
	    #Get out of here if we're in an eval
	    die $_[0];

	}	
};

# }}}

1;
